//
//  ImageAnnotateController.m
//  HandwrittenChartAnnotations
//
//  Created by kelley.ricker on 6/8/16.
//  Copyright © 2016 GrapeCity. All rights reserved.
//

#import "ImageAnnotateController.h"

@interface ImageAnnotateController (){
    CGPoint lastPoint;
    CGFloat red;
    CGFloat green;
    CGFloat blue;
    CGFloat brush;
    CGFloat opacity;

    UIButton *highlightButton;
    UIButton *redPenButton;
    UIButton *blackPenButton;
    UIButton *clearButton;
    UIBarButtonItem *shareButton;
    UIImageView *annotationsImageView;
    UIImageView *chartImageView;
}

@end

@implementation ImageAnnotateController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    red = 0.0/255.0;
    green = 0.0/255.0;
    blue = 0.0/255.0;
    brush = 5.0;
    opacity = 0.0;
    annotationsImageView = [[UIImageView alloc] init];
    chartImageView = [[UIImageView alloc] init];
    shareButton = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemAction target:self action:@selector(share:)];
    self.navigationItem.rightBarButtonItem = shareButton;
    
    [chartImageView setImage:self.chartImage];
    
    highlightButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [highlightButton setTitle:@"Highlighter" forState:UIControlStateNormal];
    [highlightButton addTarget:self action:@selector(highlightButtonClicked) forControlEvents:UIControlEventTouchUpInside];
    highlightButton.backgroundColor = [UIColor colorWithRed:255.0/255.0 green:255.0/255.0 blue:0.0 alpha:1.0];
    [highlightButton setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    
    redPenButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [redPenButton setTitle:@"Red Pen" forState:UIControlStateNormal];
    [redPenButton addTarget:self action:@selector(redPenButtonClicked) forControlEvents:UIControlEventTouchUpInside];
    redPenButton.backgroundColor = [UIColor colorWithRed:255.0/255.0 green:0.0/255.0 blue:0.0 alpha:1.0];
    [redPenButton setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    
    blackPenButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [blackPenButton setTitle:@"Black Pen" forState:UIControlStateNormal];
    [blackPenButton addTarget:self action:@selector(blackPenButtonClicked) forControlEvents:UIControlEventTouchUpInside];
    blackPenButton.backgroundColor = [UIColor colorWithRed:0.0 green:0.0/255.0 blue:0.0 alpha:1.0];
    [blackPenButton setTitleColor:[UIColor whiteColor] forState:UIControlStateNormal];
    
    clearButton = [UIButton buttonWithType:UIButtonTypeSystem];
    [clearButton setTitle:@"Clear" forState:UIControlStateNormal];
    [clearButton addTarget:self action:@selector(clearButtonClicked) forControlEvents:UIControlEventTouchUpInside];
    clearButton.layer.borderWidth = 1;
    
    clearButton.layer.borderColor = [UIColor blackColor].CGColor;
    clearButton.backgroundColor = [UIColor whiteColor];
    [clearButton setTitleColor:[UIColor blackColor] forState:UIControlStateNormal];
    
    [self.view addSubview:chartImageView];
    [self.view addSubview:annotationsImageView];
    [self.view addSubview:highlightButton];
    [self.view addSubview:redPenButton];
    [self.view addSubview:blackPenButton];
    [self.view addSubview:clearButton];
    
}
-(void)viewDidLayoutSubviews{
    
    chartImageView.frame = CGRectMake(0, 0, self.view.bounds.size.width , self.view.bounds.size.height - 30);
    annotationsImageView.frame = CGRectMake(0, 0, self.view.bounds.size.width , self.view.bounds.size.height - 30);
    blackPenButton.frame = CGRectMake(0, self.view.bounds.size.height - 30, self.view.bounds.size.width /4 , 30);
    redPenButton.frame = CGRectMake(self.view.bounds.size.width / 4  , self.view.bounds.size.height - 30, self.view.bounds.size.width / 4 , 30);
    highlightButton.frame = CGRectMake(self.view.bounds.size.width /2, self.view.bounds.size.height - 30, self.view.bounds.size.width / 4, 30);
    clearButton.frame = CGRectMake(self.view.bounds.size.width * 3/4, self.view.bounds.size.height - 30, self.view.bounds.size.width / 4, 30);
}

-(void)highlightButtonClicked{
    red = 255.0/255.0;
    green = 255.0/255.0;
    blue = 0.0/255.0;
    brush = 25.0;
    opacity = .3;
}
-(void)redPenButtonClicked{
    red = 255.0/255.0;
    green = 0.0/255.0;
    blue = 0.0/255.0;
    brush = 5.0;
    opacity = 1.0;
}
-(void)blackPenButtonClicked{
    red = 0.0/255.0;
    green = 0.0/255.0;
    blue = 0.0/255.0;
    brush = 5.0;
    opacity = 1.0;
}
-(void)clearButtonClicked{
    annotationsImageView.image = nil;
    [chartImageView setImage:self.chartImage];
}
- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
}

- (void)share:(id)sender {
    UIImage *image = chartImageView.image;
    NSArray *activityItems = @[image];
    UIActivityViewController *activityViewControntroller = [[UIActivityViewController alloc] initWithActivityItems:activityItems applicationActivities:nil];
    activityViewControntroller.excludedActivityTypes = @[];
    if (UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        activityViewControntroller.popoverPresentationController.sourceView = self.view;
        activityViewControntroller.popoverPresentationController.sourceRect = CGRectMake(self.view.bounds.size.width/2, self.view.bounds.size.height/4, 0, 0);
    }
    [self presentViewController:activityViewControntroller animated:true completion:nil];
}

- (void)touchesBegan:(NSSet *)touches withEvent:(UIEvent *)event {

    UITouch *touch = [touches anyObject];
    lastPoint = [touch locationInView:self.view];
}

- (void)touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event {

    UITouch *touch = [touches anyObject];
    CGPoint currentPoint = [touch locationInView:self.view];
    
    UIGraphicsBeginImageContext(self.view.frame.size);
    [annotationsImageView.image drawInRect:CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height)];
    CGContextMoveToPoint(UIGraphicsGetCurrentContext(), lastPoint.x, lastPoint.y);
    CGContextAddLineToPoint(UIGraphicsGetCurrentContext(), currentPoint.x, currentPoint.y);
    CGContextSetLineCap(UIGraphicsGetCurrentContext(), kCGLineCapRound);
    CGContextSetLineWidth(UIGraphicsGetCurrentContext(), brush );
    CGContextSetRGBStrokeColor(UIGraphicsGetCurrentContext(), red, green, blue, 1.0);
    CGContextSetBlendMode(UIGraphicsGetCurrentContext(),kCGBlendModeNormal);
    
    CGContextStrokePath(UIGraphicsGetCurrentContext());
    annotationsImageView.image = UIGraphicsGetImageFromCurrentImageContext();
    [annotationsImageView setAlpha:opacity];
    UIGraphicsEndImageContext();
    
    lastPoint = currentPoint;
}

- (void)touchesEnded:(NSSet *)touches withEvent:(UIEvent *)event {
    
    UIGraphicsBeginImageContext(chartImageView.frame.size);
    [chartImageView.image drawInRect:CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height - 30) blendMode:kCGBlendModeNormal alpha:1.0];
    [annotationsImageView.image drawInRect:CGRectMake(0, 0, self.view.frame.size.width, self.view.frame.size.height - 30) blendMode:kCGBlendModeNormal alpha:opacity];
    chartImageView.image = UIGraphicsGetImageFromCurrentImageContext();
    annotationsImageView.image = nil;
    UIGraphicsEndImageContext();
}

@end
